@@ -1,9 +1,12 @@
+"""Contain rules that reference things on Manifold Markets."""
+
 from __future__ import annotations
 
-from dataclasses import dataclass
 from typing import TYPE_CHECKING, cast
 
-from ...util import get_client, time_cache
+from attrs import define
+
+from ...util import get_client
 
 if TYPE_CHECKING:  # pragma: no cover
     from typing import Optional
@@ -14,23 +17,28 @@ if TYPE_CHECKING:  # pragma: no cover
 __all__ = ('this', 'other', 'user', 'ManifoldMarketMixin')
 
 
-@dataclass
+@define(slots=False)
 class ManifoldMarketMixin:
-    id_: Optional[str] = None
+    """A mixin class that holds the access to a Manifold market."""
+
+    id_: str = ''
     slug: Optional[str] = None
     url: Optional[str] = None
 
-    def __post_init__(self) -> None:
+    def __attrs_post_init__(self) -> None:
+        """Ensure we have at least the id."""
+        if hasattr(super(), '__attrs_post_init__'):
+            super().__attrs_post_init__()  # type: ignore
         if self.id_:
             return
         elif self.slug:
             slug = self.slug
         else:
-            slug = cast(str, self.url).split("/")[-1]
+            slug = self.slug = cast(str, self.url).split("/")[-1]
         self.id_ = get_client().get_market_by_slug(slug).id
 
-    @time_cache()
     def api_market(self, client: Optional[ManifoldClient] = None) -> APIMarket:
+        """Return an APIMarket object associated with this rule's market."""
         if client is None:
             client = get_client()
         return client.get_market_by_id(self.id_)
