@@ -1,31 +1,12 @@
 from __future__ import annotations
 
-from functools import lru_cache
 from pickle import dumps, loads
-from typing import TYPE_CHECKING
-
-from pytest import fixture, mark
+from urllib.parse import quote
 
 from ..market import Market
+from . import manifold_vcr, mkt
 
-if TYPE_CHECKING:  # pragma: no cover
-    from . import PytestRequest
-
-
-@lru_cache(maxsize=None)
-def fetch_slug(slug: str) -> Market:
-    """Fetch a market by slug, but cached."""
-    return Market.from_slug(slug)
-
-
-@fixture(params=(
-    "what-are-the-next-5-badges-well-add",
-    "will-the-european-union-have-an-off",
-    "my-partner-and-i-are-considering-mo"
-))
-def mkt(request: PytestRequest[str]) -> Market:
-    """Generate markets via a fixture."""
-    return fetch_slug(request.param)
+assert mkt  # just need to access it so mypy doesn't complain
 
 
 def assert_equality(mkt1: Market, mkt2: Market) -> None:
@@ -43,8 +24,11 @@ def assert_equality(mkt1: Market, mkt2: Market) -> None:
             assert mkt1.market.id == mkt2.market.id
 
 
-@mark.network
-@mark.slow
+def test_repr(mkt: Market) -> None:
+    """Make sure that repr does not error on common cases."""
+    assert repr(mkt)
+
+
 def test_get_state(mkt: Market) -> None:
     """Make sure that we are not divulging secrets."""
     state = mkt.__getstate__()
@@ -52,17 +36,23 @@ def test_get_state(mkt: Market) -> None:
     assert 'logger' not in state
 
 
-@mark.network
-@mark.slow
 def test_pickling(mkt: Market) -> None:
     """Make sure Markets can be dumped to disk and reloaded."""
-    new_mkt: Market = loads(dumps(mkt))
+    with manifold_vcr.use_cassette(f'test_market/pickle_load/{quote(mkt.id)}.yaml'):
+        new_mkt: Market = loads(dumps(mkt))
     assert_equality(mkt, new_mkt)
 
 
-@mark.network
-@mark.slow
+def test_from_url(mkt: Market) -> None:
+    """Make sure Markets can be grabbed by URL."""
+    with manifold_vcr.use_cassette(f'test_market/fetch_by_url/{quote(mkt.id)}.yaml'):
+        assert mkt.market.url
+        mkt2 = Market.from_url(mkt.market.url)
+    assert_equality(mkt, mkt2)
+
+
 def test_from_id(mkt: Market) -> None:
     """Make sure Markets can be grabbed by ID."""
-    mkt2 = Market.from_id(mkt.id)
+    with manifold_vcr.use_cassette(f'test_market/fetch_by_id/{quote(mkt.id)}.yaml'):
+        mkt2 = Market.from_id(mkt.id)
     assert_equality(mkt, mkt2)
